==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/LegendMouseButtonEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescription } from "./LegendMouseButtonEventArgsDescription";
/**
 * @hidden
 */
export let LegendMouseButtonEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendMouseButtonEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LegendMouseButtonEventArgsDescriptionMetadata.a == null) {
                LegendMouseButtonEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendMouseButtonEventArgsDescriptionMetadata.c(LegendMouseButtonEventArgsDescriptionMetadata.a);
            }
            if (a.k(LegendMouseButtonEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Handled", "Boolean");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
        }
        static d(a) {
            LegendMouseButtonEventArgsDescriptionMetadata.b(a);
            a.ad("LegendMouseButtonEventArgs", () => new LegendMouseButtonEventArgsDescription());
            a.ac("LegendMouseButtonEventArgs", LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
    }
    LegendMouseButtonEventArgsDescriptionMetadata.$t = markType(LegendMouseButtonEventArgsDescriptionMetadata, 'LegendMouseButtonEventArgsDescriptionMetadata');
    LegendMouseButtonEventArgsDescriptionMetadata.a = null;
    return LegendMouseButtonEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/LegendMouseButtonEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescription } from "./LegendMouseButtonEventArgsDescription";
/**
 * @hidden
 */
export let LegendMouseButtonEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendMouseButtonEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LegendMouseButtonEventArgsDescriptionMetadata.a == null) {
                LegendMouseButtonEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendMouseButtonEventArgsDescriptionMetadata.c(LegendMouseButtonEventArgsDescriptionMetadata.a);
            }
            if (a.k(LegendMouseButtonEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Handled", "Boolean");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
        }
        static d(a) {
            LegendMouseButtonEventArgsDescriptionMetadata.b(a);
            a.ae("LegendMouseButtonEventArgs", () => new LegendMouseButtonEventArgsDescription());
            a.ad("LegendMouseButtonEventArgs", LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
    }
    LegendMouseButtonEventArgsDescriptionMetadata.$t = markType(LegendMouseButtonEventArgsDescriptionMetadata, 'LegendMouseButtonEventArgsDescriptionMetadata');
    LegendMouseButtonEventArgsDescriptionMetadata.a = null;
    return LegendMouseButtonEventArgsDescriptionMetadata;
})();
